@@ -130,6 +130,11 @@ def filtered_column_date_format(env):
     return env["FILTERED_COLUMN_DATE_FORMAT"]
 
 
+@pytest.fixture(scope="session")
+def earliest_date():
+    return "0000-01-01"
+
+
 @pytest.fixture(scope="session")
 def custom_date_start_val():
     return "1941-03-26"
@@ -282,6 +287,17 @@ def five_column_dataset():
     return to_dc_format(df)
 
 
+@pytest.fixture(scope="session")
+def mapping_object():
+    return [
+        {'source_field_id': "First", 'destination_field_id': "newfirst", 'datatype': None, 'size': None},
+        {'source_field_id': "Last", 'destination_field_id': "newlast", 'datatype': None, 'size': None},
+        {'source_field_id': "Gender", 'destination_field_id': "newgender", 'datatype': None, 'size': None},
+        {'source_field_id': "BirthDate", 'destination_field_id': "newbirthdate", 'datatype': None, 'size': None},
+        {'source_field_id': "StartDate", 'destination_field_id': "newstartdate", 'datatype': None, 'size': None}
+    ]
+
+
 def ten_column_dataset(num_rows):
     size = num_rows
     df = pd.DataFrame(columns=['First', 'Last', 'Gender', 'Birthdate'])
