@@ -382,8 +382,6 @@ class TestGetData:
                                     custom_date_end_val):
         if filtered_column_nm not in get_three_good_field_ids:
             get_three_good_field_ids.append(filtered_column_nm)
-        else:
-            get_three_good_field_ids
         connector.authenticate()
         data = connector.get_data(good_object_id,
                                   get_three_good_field_ids,
@@ -402,6 +400,61 @@ class TestGetData:
             assert start < datetime.strptime(row[filtered_column_nm], filtered_column_date_format)
             assert datetime.strptime(row[filtered_column_nm], filtered_column_date_format) < end
 
+    @pytest.mark.source
+    @pytest.mark.get_data
+    def test_filters_no_start_selection(self,
+                                        good_object_id,
+                                        get_three_good_field_ids,
+                                        connector,
+                                        filtered_column_nm,
+                                        filtered_column_date_format,
+                                        custom_date_end_val):
+        if filtered_column_nm not in get_three_good_field_ids:
+            get_three_good_field_ids.append(filtered_column_nm)
+        connector.authenticate()
+        data = connector.get_data(good_object_id,
+                                  get_three_good_field_ids,
+                                  filters={
+                                      'filtered_column_nm': filtered_column_nm,
+                                      'start_selection_nm': None,
+                                      'end_selection_nm': "Yesterday",
+                                      'start_value_txt': None,
+                                      'end_value_txt': custom_date_end_val,
+                                      'timezone_offset_nbr': "1"
+                                  },
+                                  n_rows=5)
+        end = datetime.utcnow() - timedelta(days=1, hours=int(1))
+        for row in data["data"]:
+            assert datetime.strptime(row[filtered_column_nm], filtered_column_date_format) < end
+
+
+    @pytest.mark.source
+    @pytest.mark.get_data
+    def test_filters_no_end_selection(self,
+                                        good_object_id,
+                                        get_three_good_field_ids,
+                                        connector,
+                                        filtered_column_nm,
+                                        filtered_column_date_format,
+                                        custom_date_start_val):
+        if filtered_column_nm not in get_three_good_field_ids:
+            get_three_good_field_ids.append(filtered_column_nm)
+        connector.authenticate()
+        data = connector.get_data(good_object_id,
+                                  get_three_good_field_ids,
+                                  filters={
+                                      'filtered_column_nm': filtered_column_nm,
+                                      'start_selection_nm': "Custom Date",
+                                      'end_selection_nm': None,
+                                      'start_value_txt': custom_date_start_val,
+                                      'end_value_txt': None,
+                                      'timezone_offset_nbr': "1"
+                                  },
+                                  n_rows=5)
+        start = datetime.strptime(custom_date_start_val, "%Y-%m-%d")
+        for row in data["data"]:
+            assert start < datetime.strptime(row[filtered_column_nm], filtered_column_date_format)
+
 
 class TestGetMetaData:
     @pytest.mark.destination
@@ -479,5 +532,5 @@ class TestLoadData:
                             total_batches=1)
         connector.authenticate()
         objects = connector.get_objects()
-        assert bad_object_id in objects["object_id"]
+        assert bad_object_id in [obj["object_id"] for obj in objects]
 
